@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifndef __XFSM_DNS_H__
 #define __XFSM_DNS_H__
 
-void xfsm_dns_check (void);
+void
+xfsm_dns_check (void);
 
 #endif /* !__XFSM_DNS_H__ */
-
